@@ -181,8 +181,17 @@ void GlobalShortcutsRegistry::migrateConfig()
                 continue;
             }
 
-            const QString shortcut = value.split(QLatin1Char(','))[0];
-            const QString defaultShortcut = value.split(QLatin1Char(','))[1];
+            const QStringList triplet = value.split(QLatin1Char(','));
+            if (triplet.size() != 3) {
+                qCWarning(KGLOBALACCELD, "Not migrating %s in %s because it contains an invalid value: %s (expected a triplet: shortcut,default_shortcut,friendly_name)",
+                          qPrintable(key),
+                          qPrintable(componentName),
+                          qPrintable(value));
+                continue;
+            }
+
+            const QString shortcut = triplet[0];
+            const QString defaultShortcut = triplet[1];
 
             if (shortcut != defaultShortcut) {
                 newGroup.writeEntry(key, shortcut);
@@ -202,7 +211,7 @@ void GlobalShortcutsRegistry::migrateConfig()
         KDesktopFile file(fileName);
         const QString componentName = QFileInfo(fileName).fileName();
 
-        auto migrateTo = [this, componentName](KConfigGroup &group, const QString &actionName) {
+        auto migrateTo = [this, componentName, fileName](KConfigGroup &group, const QString &actionName) {
             QString migrateFrom = group.readEntry<QString>(QStringLiteral("X-KDE-Migrate-Shortcut"), QString());
 
             if (migrateFrom.isEmpty()) {
@@ -210,6 +219,12 @@ void GlobalShortcutsRegistry::migrateConfig()
             }
 
             const QStringList migrateFromParts = migrateFrom.split(QLatin1Char(','));
+            if (migrateFromParts.size() != 2) {
+                qCWarning(KGLOBALACCELD, "Skipping X-KDE-Migrate-Shortcut in %s because it contains an invalid value: %s (expected a value with the format: old_component,old_action_name)",
+                          qPrintable(fileName),
+                          qPrintable(migrateFrom));
+                return;
+            }
 
             if (!_config.group(migrateFromParts[0]).hasKey(migrateFromParts[1])) {
                 // Probably already migrated
@@ -217,13 +232,20 @@ void GlobalShortcutsRegistry::migrateConfig()
             }
 
             const QStringList shortcutTriple = _config.group(migrateFromParts[0]).readEntry<QStringList>(migrateFromParts[1], QStringList());
-            const QString oldShortcut = shortcutTriple[0];
-            const QString oldDefaultShortcut = shortcutTriple[1];
-            const QString newDefaultShortcut = group.readEntry<QString>("X-KDE-Shortcuts", QString());
+            if (shortcutTriple.size() != 3) {
+                qCWarning(KGLOBALACCELD, "Not migrating %s in %s because X-KDE-Migrate-Shortcut=%s points to an invalid shortcut entry",
+                          qPrintable(actionName),
+                          qPrintable(fileName),
+                          qPrintable(migrateFrom));
+            } else {
+                const QString oldShortcut = shortcutTriple[0];
+                const QString oldDefaultShortcut = shortcutTriple[1];
+                const QString newDefaultShortcut = group.readEntry<QString>("X-KDE-Shortcuts", QString());
 
-            // Only write value if it is not the old or new default
-            if (oldShortcut != oldDefaultShortcut && oldShortcut != newDefaultShortcut) {
-                _config.group(QStringLiteral("services")).group(componentName).writeEntry(actionName, oldShortcut);
+                // Only write value if it is not the old or new default
+                if (oldShortcut != oldDefaultShortcut && oldShortcut != newDefaultShortcut) {
+                    _config.group(QStringLiteral("services")).group(componentName).writeEntry(actionName, oldShortcut);
+                }
             }
 
             _config.group(migrateFromParts[0]).deleteEntry(migrateFromParts[1]);
